@@ -15,8 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""Dialog for displaying credits and information."""
-
 import nfoview
 
 from gi.repository import GObject
@@ -28,18 +26,15 @@ __all__ = ("AboutDialog",)
 
 class AboutDialog(Gtk.AboutDialog):
 
-    """Dialog for displaying credits and information."""
-
     def __init__(self, parent):
-        """Initialize an :class:`AboutDialog` instance."""
         GObject.GObject.__init__(self)
         self.set_title(_("About NFO Viewer"))
         self.set_transient_for(parent)
         self.set_authors(("Osmo Salomaa <otsaloma@iki.fi>",))
         self.set_comments(_("Viewer for NFO files"))
-        self.set_copyright("Copyright © 2005–2018 Osmo Salomaa")
+        self.set_copyright("Copyright © 2005–2021 Osmo Salomaa")
         self.set_license_type(Gtk.License.GPL_3_0)
-        self.set_logo_icon_name("nfoview")
+        self.set_logo_icon_name("io.otsaloma.nfoview")
         # TRANSLATORS: The application name "NFO Viewer" has been intentionally
         # marked as translatable. If you manage to translate the name in a
         # fluent manner, without changing the meaning, you may use that
@@ -56,15 +51,3 @@ class AboutDialog(Gtk.AboutDialog):
         self.set_website("https://otsaloma.io/nfoview/")
         self.set_website_label(_("NFO Viewer Website"))
         self.set_wrap_license(True)
-        with nfoview.util.silent(Exception, tb=True):
-            # Add donate button to the bottom of the dialog.
-            # This can fail if the dialog structure changes.
-            box = self.get_content_area()
-            button = Gtk.LinkButton(label=_("Donate"))
-            button.set_uri("https://www.paypal.me/otsaloma")
-            button.show()
-            box.pack_start(button, expand=False, fill=False, padding=0)
-            header = self.get_header_bar()
-            if header is not None:
-                switcher = header.get_children()[0]
-                switcher.get_children()[0].grab_focus()
